/* ========================================================================
 * DOM-based Routing
 * Based on http://goo.gl/EUTi53 by Paul Irish
 *
 * Only fires on body classes that match. If a body class contains a dash,
 * replace the dash with an underscore when adding it to the object below.
 *
 * .noConflict()
 * The routing is enclosed within an anonymous function so that you can
 * always reference jQuery with $, even when in .noConflict() mode.
 * ======================================================================== */
// @koala-append "animations.js"
// @koala-append "customizer.js"
// @koala-append "modules.js"
// @koala-append "page-blog.js"
// @koala-append "page-how.js"
// @koala-append "page-team.js"
// @koala-append "preloader.js"
// @koala-append "sentient.js"

(function ($) {

    var headerHeight = $('#header').height();

    var blocks = $('.block');
    var blocksHeight = [];


    blocksHeight = Array.prototype.map.call(blocks, function (block) {
        return block.offsetTop - headerHeight;
    });


    headerHeight = $('#header').height();

    function animateHeaderNav() {
         // console.log('animateHeaderNav');
        var leftNavWidth = $('#header .main-nav .left-nav').width(),
            rightNavWidth = $('#header .main-nav .right-nav').width();

        $('#header .main-nav .left-nav').css('left', 'calc(50% - ' + leftNavWidth + 'px)');
        $('#header .main-nav .right-nav').css('right', 'calc(50% - ' + rightNavWidth + 'px)');

        $(window).scroll(function () {
            // console.log('animateHeaderNav 222');
            if ($(window).width() > 1024) {
                if ($(document).scrollTop() > headerHeight) {
                    $('#header').addClass('with-logo');
                    $('#header .main-nav').addClass('full-width-nav');
                    $('#header .logo-item').addClass('showed').find('a').show('slow');
                } else {
                    $('#header').removeClass('with-logo');
                    $('#header .main-nav').removeClass('full-width-nav');
                    $('#header .logo-item').removeClass('showed').find('a').hide('fast');
                }
            }
        });
    }

    function checkOnIosAndScroll() {
        console.log('checkOnIosAndScroll');
        //console.log(navigator.userAgent);
        if (navigator.userAgent.match(/(iPod|iPhone|iPad)/)) {
            $('body').css({
                'overflow-y': 'scroll',
                'overflow-x': 'hidden',
                '-webkit-overflow-scrolling': 'touch'
            });
        }
        else {
            $('body').css({
                'overflow-y': 'auto'
            });
        }
    }


    function mobileNav() {
        $('button.navbar-toggler').toggle(function () {
                $('.navbar-toggler-icon').addClass('active');
                $('#toggle-menu').slideDown(300, function () {
                    $('body').css('overflow-y', 'hidden');
                    $('.menu-container').fadeIn(500);
                });
            },
            function () {
                $('.navbar-toggler-icon').removeClass('active');
                if ($(document).width() > 414) {
                    $('.menu-container').slideDown(500, function () {
                        $('#toggle-menu').slideUp(200, function () {
                            $('.menu-container').css('display', 'none');
                            checkOnIosAndScroll();
                        });
                    });
                }
                else {
                    $('#toggle-menu').slideUp(200);
                    $('.menu-container').slideUp(200, function () {
                        $('.menu-container').css('display', 'none');
                        checkOnIosAndScroll();
                    });
                }
            }
        );

        $('.toggle-menu-refs>.item>a').on('hover', function (e) {
            if (e.type === 'mouseenter') {
                $('.toggle-menu-refs>.item>a').each(function () {
                    $(this).css('opacity', '0.3');
                });
                $(this).css('opacity', '1');
            }
            else {
                $('.toggle-menu-refs>.item>a').each(function () {
                    $(this).css('opacity', '1');
                });
            }
        });

        $('.toggle-menu-background').on('click', function () {
            $('.navbar-toggler-icon').removeClass('active');
            $('.menu-container').slideDown(500, function () {
                $('#toggle-menu').slideUp(200, function () {
                    $('.menu-container').css('display', 'none');
                    checkOnIosAndScroll();
                });
            });
            $('button.navbar-toggler').click();
        });
    }



    function fb_share(url, title, description, image, width, height) {
      // facebook share dialog
      FB.ui({
        method: 'share_open_graph',
        action_type: 'og.shares',
        action_properties: JSON.stringify({
          object: {
            'og:url': url,
            'og:title': title,
            'og:description': description,
            'og:image': image,
            'og:image:width': width,
            'og:image:height': height
          }
        })
      },
      function (response) {
          console.log(response);
      });

    }

    function copyToClipboard(text) {
        // TODO: copy to clipboard URL
        var $temp = $("<input>");
        $("body").append($temp);
        $temp.val(text).select();
        document.execCommand("copy");
        $temp.remove();
    }

    function templateLifeBlog() {


      function shareBtnFacebook(el) {
        var url, title, description, img;
        url = sentient.decodeStr(el.data('url'));
        title = sentient.decodeStr(el.data('title'));
        description = sentient.decodeStr(el.data('description'));
        img = sentient.decodeStr(el.data('img'));
        fb_share(url, title, description, img, 500, 500);
      }

      function shareBtnTwitter(el) {
        var url, title;
        url = sentient.decodeStr(el.data('url'));
        title = sentient.decodeStr(el.data('title'));
      }

      function shareBtnCopyUrl(el) {
        var url;
        url = sentient.decodeStr(el.data('url'));
        copyToClipboard(url);
      }

      function shareBtn() {
        $('.share-btn-facebook').on('click', function (e) {
          e.preventDefault();
          shareBtnFacebook($(this));
        });

        $('.share-btn-twitter').on('click', function (e) {
          e.preventDefault();

          var data = $(this).data(),
              title = sentient.decodeStr(data.title),
              url = sentient.decodeStr(data.url),
              twtr_url = "http://twitter.com/share?text=" + title + "&url=" + url;
          window.open(twtr_url, title, 'width=640,height=580');

        });

        new Clipboard('.share-btn-copy-url', {
          text: function () {
            return window.location.href;
          }
        });
      }

      function setVideoVimeo() {
        $('.blog-video-vimeo').each(function () {
          var id;
          id = $(this).data("ref");
          if (id !== '') {
            id = id.split('/')[3];
            $(this).attr('src', 'https://player.vimeo.com/video/' + id + '?portrait=0&title=0&byline=0&autoplay=0&loop=1');
          }

        });
      }

      setVideoVimeo();
      shareBtn();
    }

    function template_common() {

        // showThankYou();
        if (navigator.userAgent.match(/(iPhone)/)) {
            $('html').addClass('its-iPhone');
        }
        if (navigator.userAgent.match(/(iPod|iPhone|iPad|Android)/)) {
            $('html').addClass('its-TP');
        } else {
            $('html').addClass('its-noTP');
        }


        $('body').on('touchstart', function (e) {
            if ($('*').is('.hover')) {
                if (!$(e.target).closest(".share-btn").length) {
                    $('.share-btn').removeClass('hover');
                    e.stopPropagation();
                }
            }
        });

        if ($('html').is('.its-TP') && $('*').is('.share-btn')) {
            $('.share-btn').on('click', function (e) {
                $('.share-btn').addClass('hover');
            });
        }
    }


    // start KP js refactored

    function homeScroll() {
      var headerHeight = $('#header').height(),
          intro = $('.home .page-intro');

      $(window).scroll(function() {
        if ( $(document).scrollTop() > headerHeight ) {
          intro.addClass('animate');
        } else {
          intro.removeClass('animate');
        }
      });
    }

    function global_events() {



      $(window).scroll( function(){
        Animations.check_if_in_view( $('.page-animation .module') );
      });

    }
    // end KP JS refactored


    // Use this variable to set up the common and page specific functions. If you
    // rename this variable, you will also need to rename the namespace below.
    var Sage = {
      // All pages
      'common': {
        init: function () {

          sentient.init();

          template_common();
          animateHeaderNav();
          mobileNav();

          global_events();
          PageLoader.init();
        },
        finalize: function() {

          PageLoader.loadIntro($('.page-intro'));

          $(window).on('resize', function () {
            PageLoader.loadIntro($('.page-intro'));
          });

          $('.page-intro').not('.home-intro').addClass('animate');
          Animations.init();
        }
      },
      // Home page
      'home': {
        init: function () {
          homeScroll();
          Modules.init();
        }
      },
      'archive' : {
        init: function () {
          console.log('tempate_life');
          Blog.init();
        }
      },
      'page_template': {
        init: function () {
          Modules.init();
        }
      },
      // How it works  page.
      'template_how_it_works': {
        init: function () {
          How.init();
        }
      },
      'template_life': {
        init: function () {
          console.log('tempate_life s');
          Blog.init();
        }
      },
      'template_life_blog': {
        init: function () {
          templateLifeBlog();
        }
      },
      'template_team': {
        init: function () {
          Team.init();
        }
      }
    };

    // The routing fires all common scripts, followed by the page specific scripts.
    // Add additional events for more control over timing e.g. a finalize event
    var UTIL = {
        fire: function (func, funcname, args) {

            var fire;
            var namespace = Sage;
            funcname = (funcname === undefined) ? 'init' : funcname;
            fire = func !== '';
            fire = fire && namespace[func];
            fire = fire && typeof namespace[func][funcname] === 'function';

            if (fire) {
                namespace[func][funcname](args);
            }
        },
        loadEvents: function () {
            // Fire common init JS
            UTIL.fire('common');

            // Fire page-specific init JS, and then finalize JS
            $.each(document.body.className.replace(/-/g, '_').split(/\s+/), function (i, classnm) {

                UTIL.fire(classnm);
                UTIL.fire(classnm, 'finalize');
            });

            // Fire common finalize JS
            UTIL.fire('common', 'finalize');
        }
    };

    var getThisAttr;

    if (navigator.userAgent.match(/(iPod|iPhone|iPad)/)) {
      $('#header-static > .tel-link').css({
          'position': 'absolute!important'
      });
      $('#content > .page-career > .articles-container').css({
          'padding-bottom': '70px'
      });

      $('#content > .page-legal').css({
          'padding-bottom': '70px'
      });

      $('#content > .page-how-it-works > .how-it-works-content > .content-footer-wrapper > .content-footer').css({
          'padding-bottom': '70px'
      });
    }

    function checkOnMinWidth() {
      if (window.matchMedia('(min-width: 1024px)').matches) {
        $('.overlay-team > .shell-container > .overlay-main-container').css({
          'max-width': '850px!important'
        });
      }
      else {
        $('.overlay-team > .shell-container > .overlay-main-container').css({
          'max-width': '100%!important'
        });
      }
    }

    if (navigator.userAgent.match(/(iPod|iPad)/)) {
      checkOnMinWidth();
    }

    $(window).on('resize', function () {
      if (navigator.userAgent.match(/(iPod|iPad)/)) {
        checkOnMinWidth();
      }
    });


    // Load Events
    $(document).ready(UTIL.loadEvents);

})(jQuery);
// Fully reference jQuery after this point.



window.fbAsyncInit = function () {
    FB.init({
        appId: sj.facebook_app_id, //131141124179342
        autoLogAppEvents: true,
        xfbml: true,
        version: 'v2.11'
    });
    FB.AppEvents.logPageView();
};

(function (d, s, id) {
    var js, fjs = d.getElementsByTagName(s)[0];
    if (d.getElementById(id)) {
        return;
    }
    js = d.createElement(s);
    js.id = id;
    js.src = "https://connect.facebook.net/en_US/sdk.js";
    fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));
